pub struct AgentModeContext {
pub active: bool,
}Expand description
Shared process-level agent-mode context.
Fields
active: boolWhether agent mode is active for the current process.
Implementations
Sourceimpl AgentModeContext
impl AgentModeContext
Sourcepub fn from_tokens(
presented: Option<String>,
expected: Option<String>,
) -> AgentModeContext
pub fn from_tokens( presented: Option<String>, expected: Option<String>, ) -> AgentModeContext
Construct an agent-mode context from edge-read token values.
Agent mode is active only when both the presented and expected tokens
are present and equal. Reading the tokens from the environment is the
binary edge’s responsibility (REPO_INVARIANTS.md #5).